# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .batch.client import AsyncBatchClient, BatchClient
from .raw_client import AsyncRawExpressionMeasurementClient, RawExpressionMeasurementClient


class ExpressionMeasurementClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawExpressionMeasurementClient(client_wrapper=client_wrapper)
        self.batch = BatchClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawExpressionMeasurementClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawExpressionMeasurementClient
        """
        return self._raw_client


class AsyncExpressionMeasurementClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawExpressionMeasurementClient(client_wrapper=client_wrapper)
        self.batch = AsyncBatchClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawExpressionMeasurementClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawExpressionMeasurementClient
        """
        return self._raw_client
