# This file was auto-generated by Fern from our API Definition.

import typing

ModelProviderEnum = typing.Union[
    typing.Literal[
        "GROQ",
        "OPEN_AI",
        "FIREWORKS",
        "ANTHROPIC",
        "CUSTOM_LANGUAGE_MODEL",
        "GOOGLE",
        "HUME_AI",
        "AMAZON_BEDROCK",
        "PERPLEXITY",
        "SAMBANOVA",
        "CEREBRAS",
    ],
    typing.Any,
]
