# This file was auto-generated by Fern from our API Definition.

import typing

ReturnChatAudioReconstructionStatus = typing.Union[
    typing.Literal["QUEUED", "IN_PROGRESS", "COMPLETE", "ERROR", "CANCELLED"], typing.Any
]
