# This file was auto-generated by Fern from our API Definition.

import typing

from .format_mp_3 import FormatMp3
from .format_pcm import FormatPcm
from .format_wav import FormatWav

Format = typing.Union[FormatMp3, FormatPcm, FormatWav]
