# This file was auto-generated by Fern from our API Definition.

import typing

from .task_classification import TaskClassification
from .task_regression import TaskRegression

Task = typing.Union[TaskClassification, TaskRegression]
