# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .embedding_generation_base_request import EmbeddingGenerationBaseRequest
from .state_embedding_generation import StateEmbeddingGeneration


class JobEmbeddingGeneration(UniversalBaseModel):
    job_id: str = pydantic.Field()
    """
    The ID associated with this job.
    """

    user_id: str
    request: EmbeddingGenerationBaseRequest
    state: StateEmbeddingGeneration

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
