# This file was auto-generated by Fern from our API Definition.

import typing

from .posted_context_with_generation_id import PostedContextWithGenerationId
from .posted_context_with_utterances import PostedContextWithUtterances

PostedContext = typing.Union[PostedContextWithGenerationId, PostedContextWithUtterances]
