# This file was auto-generated by Fern from our API Definition.

import typing

from .completed_state import CompletedState
from .failed_state import FailedState
from .in_progress_state import InProgressState
from .queued_state import QueuedState

StateInference = typing.Union[QueuedState, InProgressState, CompletedState, FailedState]
