# This file was auto-generated by Fern from our API Definition.

import typing

from .source_file import SourceFile
from .source_text_source import SourceTextSource
from .source_url import SourceUrl

Source = typing.Union[SourceUrl, SourceFile, SourceTextSource]
